
# q-expansion of newform 261.2.k.b, downloaded from the LMFDB on 06 May 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 261
weight = 2
poly_data = [49, -392, 7938, -19712, 23373, -15449, 7428, -3280, 2349, -822, 762, -387, 272, -115, 66, -32, 15, -5, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[686412643659543375911717496442488, 37392949665639819543403712919956232, -121149684916712370234099590037749063, 105356175167695476032412081972344547, -92747861809356536255114033697415786, 36383674231236096303018128645723623, -20223002746450034256279988124885241, 11855860833695328374400512211554933, -4965218224227953302289873278282478, 4038749024756350400116794155089795, -2184006048411592938278265445872122, 1481971961971026104211218599724381, -636445862796561099097710383293198, 361717179646273498961683350642018, -176951008274646812434954319205108, 81803634885395038607989701482861, -27585561900525695034512466127561, 5455805379009686962199379931615], 40363101898809785237202310415513551], [[3299340919613125492110280724953777, -35730677441481621935679104551795026, 88345981684958706335892385442430416, -14979640095924670918975932431079560, -18892878436426721013106781538315038, 31215200630044754989124665691690436, 12194997538629224348658098370510038, 13298802941657250027094637880240822, 3951977550151930687207566077510271, 2453532680440059206804458464772812, 849073097452027665928298529435842, 792049354316340760514995855510559, -45898674684547881690487621863076, 121681091831071442730638406072826, -41058634042643477417156065121721, 39579636376183227400622449620793, -20460048908034063879157736786858, 8181278388234115556096961407666], 40363101898809785237202310415513551], [[-2137632163203089504494749641290989, -21845104777410344900974136054073015, 85566834186377311478542321942139219, -135943011969857351614946028809398678, 80803301112353649348119671544815550, -67036248205137567976909438573608657, 8573878572059550391854739553447218, -21108570932649850405563395272628154, 1832154246902015755070257484578976, -5901254113845935696046133237916061, 1660559941026102853182281024076856, -1921868809445842060118910293508029, 652658671116922292614898824135383, -426734744787058002868706036098187, 196550274514724209618453939729120, -100875527053784609832954017170404, 35105246782144053130283493617649, -9113651791436261426445398973083], 40363101898809785237202310415513551], [[-2580170504361960267276809725697815, 12409888196496453208395396369627035, 120987530299161094128634976026396355, -209400856993612463681417099532784086, 182250539938519185050533559784777424, -66039459615678935755364686366307509, 38100516440645020342213924611973123, -22901474247764159996246992871560316, 8464074729516143184962382544635833, -7228399922104977424341071633899055, 3951451884292541248893538955244348, -2870170677302253001114003375704052, 1175888304688410748029567613466783, -683497715272779024877011321280289, 340299745462353400442505285026605, -170043210404474412973759700439252, 61932386753331092958710264562409, -12742154098912301511089208709020], 40363101898809785237202310415513551], [[-42884250814916166550697452891496136, 232348533189558397131797824461432119, -381490175817020354113468720541208291, 420166692834958726565003279500482562, -252799774882180700679755345024090911, 124277556156717140302652183299881177, -57803482694987211496654254830562293, 37870999855988512282220983464882566, -15553671332677669889901116238267859, 12858423078382451151435994676263466, -6903231004751501338452742500198725, 4446736456171985553138264649259662, -1972685629051324279162652985149898, 1101506814020154216724206457270500, -530073116458974386142172556302445, 237711881388141014191160679324241, -75497911874881460014415450997175, 14008421299174354610443214213112], 40363101898809785237202310415513551], [[-3226996409584576229339997670932030, 52578543983916729067492781130231224, -268553466519941513390791403306527887, 437745659632303188581010797271586068, -319746950445029613252423087458452184, 158065647826286453838869662939358761, -59831903595451523019476676379964973, 53000587702883021668648539991501549, -13334780853502247247965512473718793, 15731579858284531264039741241841141, -7053972966973529124756141969018968, 5822063442576531254088561791438338, -2255156116607073761492475111101413, 1348034139833757835656243731331540, -653090320094936831444120361658937, 327819280026705021816418347151739, -116875999496042819828416242944682, 25810688189928638684993581103478], 40363101898809785237202310415513551], [[128652752444748499652092358674488408, -697045599568675191395393473384296357, 1184833629349870847577608472039138424, -1260500078504876179695009838501447686, 758399324646542102039266035072272733, -372832668470151420907956549899643531, 173410448084961634489962764491686879, -113612999567965536846662950394647698, 46661013998033009669703348714803577, -38575269235147353454307984028790398, 20709693014254504015358227500596175, -13340209368515956659414793947778986, 5918056887153972837487958955449694, -3304520442060462650172619371811500, 1590219349376923158426517668907335, -713135644164423042573482037972723, 226493735624644380043246352991525, -42025263897523063831329642639336], 40363101898809785237202310415513551], [[-38946162083035060936932133184400927, 431863244625277811206691763831279437, -995881893624128786565976741648745110, 1100453842960227342992115250440617303, -741001131660740216036896932620639046, 332621464455172792011997603543436326, -164199050428693392747252759016188234, 104307622642086857511359378043610265, -41761124280232457587774382322430203, 34902921336143535555733285649867338, -18804800384131467330312137052275636, 12518698434203459950218407037015975, -5443626556386145615458424581985202, 3075809922910722317713422844325146, -1496880205063965510727484395156356, 689482439599416350424594608298564, -227239382730527027191215770533388, 43625146187818153152954074312061], 40363101898809785237202310415513551], [[-8231475838399228929819081435955485, 538975152005798657427478151589442385, -1247366591319795336917345126327790806, 1412991870519174232541571798942635179, -879530360062371265738210267025604324, 429233302285556058410216835683062303, -195614928417299459520082419408067116, 132154289316174197630538424292884148, -50512076546299494561107144991523625, 44075736054166290711443110607932818, -23248252007671204499810439372541897, 15498467430942557537811042009177103, -6738999919387583733791972922407814, 3815631445215197842080657160456315, -1855052519375550505889227276405172, 851780500333523011512835690796434, -276024858625642941029131017453695, 52656540905346127903608361748935], 40363101898809785237202310415513551], [[-64137985617382064092576931651998938, -21005852439438222358056815775919737, 454172712952364273257505338536393997, -815592289191024873375976485686200060, 688392440349927563863430787269603521, -364784927127412981016333206968339401, 100672450188142953787981235294893032, -127749256226329559312987778301657590, 20577172764588671730782985248935725, -35957236066292509648953656042374812, 12730193161179096182033435704042829, -13145107290481144488816950024559549, 4654742448865054505097975022443675, -2951670907935319523343914822147646, 1397323531787919369792469681834778, -725936841149419789763439612432086, 269018350084411635069502428809649, -66059494663468928213582382802343], 40363101898809785237202310415513551], [[-9335950084576617998796858752164810, -446147247292367623385973092000081458, 1312298078422726955621388427778897016, -1592678497091887580749710687341266667, 1071450259142354463715894602830688413, -487958152479458452292059559281666606, 234152644091270548274476694571024262, -154214386126811983210079156839151406, 57801659944154123584654473891548418, -50459044876939842231786679274947384, 26850109270444495157385988519941410, -18360607452945162858302658176708532, 7865032229698610862989460515658221, -4485068852297057405565697449753339, 2194251257348020283472642514896729, -1030462371238582683912917142384953, 344848719165083655567350096607031, -67333488155369908002250627039873], 40363101898809785237202310415513551], [[145203367590110264920082577419790056, 38102001442365194743314079396407976, -841606680395071280125348488265831561, 1332883301810709099179605391830388024, -925088235640475920834796060176300575, 442945940828244137469806428519922633, -185393568080737685164864716226527630, 143698580347089787461734634483822905, -42051587262782588037144547569235683, 44177848479917160751645250886566583, -21773379831721918219191782353423972, 16473355937503745204447663191594162, -6670528883455111482197859149544568, 3929289127262054239366350737056589, -1932994676965097283924073630550660, 953125373068321922908044047203704, -331772354024210041260825545516245, 69040107155947589727638312731259], 40363101898809785237202310415513551], [[27229866382664407319280131133763653, -546562567981910283878687218343669218, 1409889126699040291141944414005501181, -1720130860479368516361728884117629379, 1155641677865598397562498283101675315, -578973467374290147696546483523825033, 230868452590268602097661655575188846, -185740001573267895314278160355054678, 57320800888936477624928605850584750, -58790303490533332060362442077370478, 27964334602789960422125469299987950, -20867788766095361322860936139603311, 8570437479276286705607340928522407, -4998341974215445810885358721435705, 2407215297273294679040170609737655, -1144068731560553322374323276563172, 386392270043069706743383339986749, -80796847221978717001827730949481], 40363101898809785237202310415513551], [[145381015827594909240521500503608830, -1612971667840846525294343493216348392, 3724995604001745901866178462485849707, -4250718822320666401949660784051415200, 2701462221895485242118701780646952143, -1312141969581912308644270946412791981, 591272950281011870606276746432221639, -408151849189622739542960533685241422, 151085832776786833458845985387674712, -134754406879648895394665809718441372, 70119462095962289573437711416347836, -47591835705545209160913770015744119, 20499525511138984563849809535952999, -11647943729812770137885839284390307, 5649556086584229416051351851252896, -2611182770721004021331731389847894, 854329210227038173596920623724757, -165868034827429968789957308798334], 40363101898809785237202310415513551], [[25556433852472056824479254731138599, -1619862461201713975429520979337979738, 3877302302869482706680164728155026847, -4490945641400598214317462851456645649, 2866989777326384125522045954506957369, -1391144340983090234436313693421971419, 624929094329515344919539403929497462, -432979002857137151410262803324684289, 158714551632046184061247367408242985, -142636011718267989145765020911781495, 74055626638403380987363078975356931, -50526599068074063207250143933771137, 21697969256223043032079501804660677, -12361016755047489825167626000188864, 6005027367285761733604684472750904, -2784034472703783627807405623500253, 913670253049262732055405993125188, -178045476281030342386508971371042], 40363101898809785237202310415513551], [[-28632215804576556770433947483236410, -1330866646965967287698295496460610719, 3823337127834518564260743748234863253, -4647849679977064548991176555977994116, 3125929266666798631610412832868924865, -1449271458702798395881895052284127262, 673848671242770004954424127788779735, -458949409376648621016078790563841741, 166375134101881534500661863288717590, -149367158691029758038207090810663545, 78069206310067289145049060157450045, -54102060606848969139009989714979204, 22999401451493939579066120153825275, -13165747140204668290951400961189500, 6425269316788627975563051091175156, -3023937928012907803826402033492824, 1013457056416040857009471859625045, -200222080724879309410016102136928], 40363101898809785237202310415513551]]

hecke_ring_character_values = [[146, [1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [118, [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0]]]
aps_data = [[0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 1, -1, 0, 0], [0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, -1, 0, 0, -1, -1, 0, 1], [1, -1, 1, 0, 1, 2, 1, 1, -1, -1, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 1, 1, 0, -1, 0, -1, 0, -1, 0, 0, 0, 0, 0], [1, 2, -1, -1, -1, -1, 0, -2, 0, 1, -1, 0, 1, 1, -1, 1, -1, 0], [1, 0, 0, -1, -1, 0, 1, 0, 0, 0, -1, 0, -1, 0, -1, 0, 0, 0], [1, -1, 0, -1, 1, -1, 0, 0, 1, 0, 0, 0, -1, -1, -1, 0, 0, -1], [1, -2, 0, 1, 1, 1, -1, 2, -1, 0, 1, -1, 1, 1, -1, 1, 0, 1], [0, 0, -2, -1, -2, -1, -1, -1, 2, 1, 0, 2, 0, 1, 1, 1, 0, 1], [3, 2, 0, -1, 1, -2, 3, -1, 0, -3, -3, 0, -3, 0, -3, 0, 0, 0], [3, 0, -1, -1, -1, -1, 0, 0, 0, 2, 2, 0, 2, -1, 2, -1, 1, 0], [-1, 1, 2, -2, -1, -2, -1, 0, 2, 1, 0, -1, 3, -2, 1, 0, -1, -1], [-2, 0, 0, 0, -2, 0, 0, -2, 1, 2, 0, 0, 0, -1, 0, -1, 1, -1], [0, 0, 3, 1, 3, 2, -1, 2, 1, -4, 0, 1, 0, -1, 1, 0, 0, -1], [-4, 0, 1, 1, 0, 0, 0, 0, 0, 5, 4, -2, 5, -1, 4, 1, -1, 0], [0, 2, -2, -2, 0, -2, -1, -1, 0, 0, 0, 0, 1, 0, 5, 0, 0, 0], [-1, -3, 0, 4, 3, 3, 0, 4, -2, 3, 0, 0, 1, 0, 3, 0, 2, 0], [3, 2, -2, 0, -3, -1, 2, -3, -1, -3, -3, 0, -3, 2, 0, 2, -2, 2], [5, -2, 4, 2, 2, 2, 6, 0, -1, -6, 0, 1, -2, 1, -5, 0, 1, 1], [0, 2, 0, 1, 0, -2, 0, 1, 1, -1, 0, -2, 0, 2, -1, -1, -2, 1], [1, 1, -1, -1, -1, 0, 1, -1, -3, 0, -4, -1, 0, 0, 0, 2, -2, -1], [-1, 0, -1, 0, -1, 0, 0, 0, 3, 5, 1, 3, 0, 2, 0, 2, 0, 2], [-5, -2, -1, 2, 2, 0, -5, -1, -2, 0, 4, 0, -1, 0, -1, 2, -1, 0], [-2, 1, -1, -1, -1, -1, 1, 0, -1, -1, 0, -2, -3, 1, 2, 0, -2, -3], [-1, 3, -3, 0, -3, -2, 3, -3, 1, 1, 0, 0, 0, 3, 0, 3, -2, 2], [-7, 0, 0, 1, 3, 0, 1, 1, 1, -2, -1, 1, 7, -1, -2, 0, 0, 0], [0, 4, -5, -4, 0, -5, -4, -4, 4, 1, 1, -1, 4, -4, -3, -1, -4, 0], [0, 2, -1, -2, 0, -1, 5, -2, 0, -1, -1, 1, -5, -2, -8, 1, -2, -2], [-1, -1, 1, 0, -3, -1, -2, -3, 2, 1, 0, 0, 0, -3, 0, -3, 3, -3], [-1, -5, 1, 3, 5, 3, -2, 0, 0, 2, 0, 5, 0, 0, 1, 0, 5, -1], [-2, 3, 0, -1, 1, -3, -2, -1, 1, -2, 2, -1, 2, 1, -2, -3, 1, 3], [2, -2, 0, 2, 2, 2, 8, 0, 0, -8, 0, 0, -6, 0, -2, 0, 0, 1], [-4, 0, 2, -1, -1, 0, -4, 2, 0, 0, 2, -2, -4, 0, -4, -2, 2, -2], [-3, 5, -7, -2, -5, -2, -5, 0, 0, 5, 0, 0, 6, 0, 3, 0, 0, 1], [-8, 1, 0, 0, -1, -1, 0, -1, 0, 0, -1, 0, 0, 2, -1, -1, 1, 0], [3, 3, -3, 0, -5, -2, 5, -5, 2, -3, -4, 0, -4, 0, 0, 0, -2, 2], [0, -1, -1, 1, 0, -1, -1, 1, 4, 11, 11, 3, 1, -3, 3, 3, -3, 1], [2, 2, -2, -2, -2, -2, 0, -2, 0, -1, 4, 4, -1, 2, 4, 3, -3, 0], [5, 0, 3, 1, 3, 0, -1, 0, -1, -6, -5, -1, 0, 0, 1, 1, 0, 0], [0, -6, 4, 6, 0, 4, 2, 2, -1, -1, -1, 1, -2, 2, -4, 1, 2, 1], [1, 0, 2, 2, 3, 3, 0, 0, 0, 1, 1, -1, 1, 1, 1, -2, 2, 0], [-7, -5, 6, 5, 5, 0, -7, 6, 2, 0, 10, -4, 8, 0, 8, -6, 2, -4], [1, 4, 0, 1, -4, 1, 0, 0, -1, 0, 0, -2, -3, 1, -1, 0, -2, -1], [-3, 2, 3, 1, 1, 0, -3, 3, -1, 0, 7, 0, 4, 0, 4, 1, 2, 0], [6, 1, 0, 2, 0, -1, 5, 2, 0, -6, -5, 3, -6, -3, -6, 0, 3, 0], [-4, -6, 0, 2, 4, 6, -2, 2, -4, 12, 2, -1, 4, 1, 12, 0, 3, 0], [-4, 0, 0, 6, 0, 3, -3, 3, -1, -2, 4, -1, 0, 8, 3, 0, 0, 8], [0, 5, -2, -5, 0, -2, -3, -3, 3, -1, -1, 2, 3, 0, -3, 2, 0, 3], [3, 6, -6, -6, -4, -4, 0, -6, 0, -1, -5, 2, -1, -3, -5, -2, 2, 0], [0, 0, 1, 0, 0, 1, -5, 3, -5, 0, 0, -1, 5, 5, -3, -1, 5, 0], [2, 3, 0, 1, -4, -3, -2, 1, -4, -1, 2, 1, -2, -1, -1, 4, 1, -4], [1, -3, -1, -3, -3, 0, 1, -1, -1, 0, -6, -2, -6, 0, -6, -1, 4, -2], [-2, -5, -3, 3, 3, 0, -2, -3, 1, 0, -2, 2, 2, 0, 2, 1, 2, 2], [0, 0, -4, -2, -4, 1, -11, 1, 0, 0, 0, 0, 0, -5, 11, -1, 0, -5], [7, 0, 0, -1, 4, 0, 2, -1, 0, -3, -2, 1, -7, -1, -3, 2, -1, -2], [4, -5, 4, 0, 0, 0, 4, 4, 1, 0, -5, -2, -6, 0, -6, -3, 4, -2], [4, 0, 0, 0, 1, 0, 2, 1, -1, -4, 0, 0, 0, -3, 0, -3, 1, -1], [5, 1, 0, -4, -3, -1, 6, -4, -4, 2, -6, 2, -5, -2, 2, 1, 5, -1], [0, 6, -6, -6, 0, -6, -4, -8, -2, 2, 2, 6, 4, 1, 0, 6, 1, -1], [0, 2, -5, -2, 0, -5, 0, -3, -5, -3, -3, 5, 0, 5, -6, 5, 5, 0], [-4, 1, -3, -3, 0, 0, 0, -1, 0, 1, 1, 0, 1, -4, 1, -1, 1, 0], [0, 4, 0, -2, -6, -4, 10, -2, -3, -6, -10, -2, 0, 2, -6, 2, -1, -2], [3, -4, -5, 1, 4, 1, -7, 0, -3, 7, 0, 0, -3, 3, -3, 0, 0, -5], [-6, 0, 1, 2, 1, 0, -1, 0, 0, -3, 6, 0, 0, -3, 1, 0, 0, -3], [-3, 3, 3, 3, -1, -1, 0, -3, 0, -2, 4, 0, -2, 2, 4, 1, -1, 0], [2, -3, 3, 0, 2, 1, -3, 2, -8, -2, -4, 0, -4, -3, 0, -3, 4, -4], [-1, -3, -2, -2, -3, -3, 0, 3, 0, 3, 6, -3, 3, -1, 6, 1, -1, 0], [7, 1, 2, 2, -3, -3, 0, -1, 0, 10, 4, -1, 10, 2, 4, 1, -1, 0], [5, 0, 4, 4, 4, 3, 0, 3, -4, -7, -5, -4, 0, 4, 0, -1, 0, 4], [3, -3, 3, 0, 3, -1, 12, 3, 5, -3, -2, 0, -2, -1, 0, -1, 1, -1], [-5, 4, -2, -1, -1, 0, -5, -2, -4, 0, -7, 1, 1, 0, 1, 5, -3, 1], [-3, 2, 0, 3, 3, 0, -3, 0, 0, 0, -1, 0, 6, 0, 6, 0, -7, 0], [-2, 0, 0, -3, 0, 1, -9, 1, -1, 13, 2, -1, 0, -5, 9, 1, 0, -5], [-9, 1, 4, 2, -1, 2, -13, 0, -1, 13, 0, 3, 3, 1, 9, 0, 3, 2], [1, 0, -2, -2, -1, -1, 0, 0, 0, 2, 7, -6, 2, 1, 7, 2, -2, 0], [-4, -4, 0, 3, 4, 4, 1, 3, 5, -3, -1, -1, 4, 1, -3, -6, 0, 6], [-11, 0, -2, 4, -2, 0, -13, 0, 0, -1, 11, 0, 0, 3, 13, -2, 0, 3], [0, 2, 0, -2, 0, 0, 8, -3, 9, -7, -7, 4, -8, -1, -9, 4, -1, 8], [-10, 1, -1, 0, 0, -3, -11, 0, 6, 10, 11, 0, 11, -4, 0, -4, -3, 3], [4, 2, -1, -5, -2, -5, 1, 0, 1, -1, 0, 0, 3, -1, -4, 0, 0, -4], [-5, 0, 5, 7, 7, 0, -5, 5, -3, 0, -3, -1, 2, 0, 2, 2, 0, -1], [3, 0, 7, 0, 7, 0, -5, 0, 3, -3, -3, 3, 0, -5, 5, 1, 0, -5], [1, -5, 3, 1, 1, 0, 1, 3, 3, 0, 6, 4, 4, 0, 4, 1, 0, 4], [10, -1, 0, 2, -2, 1, 19, 2, -6, -16, -19, -5, -10, 5, -16, 3, -2, -3], [14, -3, -1, -1, 3, -1, 4, 0, 5, -4, 0, 4, -10, -5, -14, 0, 4, -4], [0, 1, 0, -1, 0, 0, 12, 3, 1, -8, -8, -5, -12, 3, -3, -5, 3, 4], [0, 4, -5, -4, 0, -5, 5, -10, 9, -6, -6, 5, -5, -6, -6, 5, -6, 3], [12, -1, 2, 2, -4, -4, 0, 1, 0, 8, -1, 1, 8, 3, -1, 8, -8, 0], [0, 0, 8, 0, 0, 8, 4, 5, -4, 0, 0, 2, -4, 0, 11, 2, 0, -4], [11, 5, -1, -3, -5, -3, 0, 0, -5, 0, 0, -1, 2, 5, -11, 0, -1, 2], [12, 4, -4, -4, -4, -4, 2, 0, 4, -2, 0, -1, -2, -4, -12, 0, -1, -2], [-10, 0, 0, -3, 0, -7, -7, -7, 4, 1, 10, 4, 0, -3, 7, 0, 0, -3], [2, -4, 5, 7, 4, 7, 7, 0, -2, -7, 0, 5, -5, 2, -2, 0, 5, 2], [7, -10, 7, 3, 3, 0, 7, 7, -1, 0, -7, -4, -4, 0, -4, -3, 1, -4], [0, -5, 5, 0, 6, 4, -12, 6, 2, 0, 16, 0, 16, 3, 0, 3, -1, 1], [4, 1, 2, 2, 3, 3, 0, -1, 0, 0, -11, -4, 0, 1, -11, -2, 2, 0], [3, 5, -3, -3, 5, 5, 0, -5, 0, -10, -4, 7, -10, -2, -4, 2, -2, 0], [-9, 11, -4, -6, -6, 0, -9, -4, 0, 0, 9, 3, 8, 0, 8, 3, 1, 3], [9, -7, 6, 5, 5, 0, 9, 6, 1, 0, 8, 3, -7, 0, -7, 2, 5, 3], [-20, 2, -1, -5, -2, -5, -12, 0, -2, 12, 0, -1, 13, 2, 20, 0, -1, -3], [-10, 5, 4, 4, 6, 6, 0, -5, 0, -2, 3, 6, -2, 0, 3, 3, -3, 0], [5, -1, 1, 0, -5, -2, 21, -5, -8, -5, -7, 0, -7, 7, 0, 7, 2, -2], [-10, 2, 0, -4, 2, -2, 10, -4, 3, 10, -10, 0, 10, 0, 10, -1, -2, 1], [0, -8, 0, 8, 0, 0, 3, -1, 1, -3, -3, -1, -3, 1, 8, -1, 1, 2], [0, 1, 0, -1, 0, 0, -6, -5, -2, 1, 1, -4, 6, -4, 1, -4, -4, -6], [-3, 1, -1, 0, 0, 3, 6, 0, 11, 3, 2, 0, 2, -9, 0, -9, -2, 2], [9, 3, 2, 7, 7, 0, 9, 2, -6, 0, 4, 1, -9, 0, -9, 7, 1, 1], [5, 3, 0, -3, -7, -3, 12, -3, 8, -10, -12, 3, -5, -3, -10, 0, -5, 0], [5, 0, 1, 4, 1, 5, -14, 5, 8, 7, -5, 8, 0, -3, 14, 0, 0, -3], [-2, -3, 4, -9, -9, 0, -2, 4, 4, 0, 4, -3, -1, 0, -1, -7, -1, -3], [-6, -3, 0, 9, 1, 3, -8, 9, 11, 4, 8, 1, 6, -1, 4, -7, -3, 7], [-15, 11, -3, -1, -1, 0, -15, -3, -5, 0, 0, -1, 12, 0, 12, 4, -10, -1], [0, -4, 1, 4, 0, 1, -7, 4, 3, -2, -2, 0, 7, 1, -2, 0, 1, 4], [0, -2, 9, 2, 0, 9, -7, 4, 4, 4, 4, 2, 7, 0, 6, 2, 0, 4], [-12, 0, 0, -7, 0, -8, -10, -8, 4, 13, 12, 4, 0, -3, 10, -4, 0, -3], [3, -8, 0, 1, -1, 8, -7, 1, -4, 6, 7, 3, -3, -3, 6, 0, 7, 0], [8, 2, -9, -3, -2, -3, -2, 0, -2, 2, 0, 5, -11, 2, -8, 0, 5, 9], [7, -2, 0, 2, 3, 2, 5, 2, 7, -13, -5, -2, -7, 2, -13, -12, 3, 12], [-7, 7, 1, 2, -7, 2, -6, 0, -6, 6, 0, -5, -2, 6, 7, 0, -5, -3], [1, -8, 12, 9, 8, 9, 0, 0, -2, 0, 0, -4, -3, 2, -1, 0, -4, -5], [-7, 3, 6, -5, -5, 0, -7, 6, 2, 0, 14, 1, 8, 0, 8, -1, 0, 1], [5, -9, 9, 0, -3, -7, 4, -3, -6, -5, -2, 0, -2, 1, 0, 1, 6, -6], [12, 0, 0, 1, 0, -4, 6, -4, 2, -13, -12, 2, 0, -7, -6, 2, 0, -7], [8, 0, -11, -9, -11, -4, 17, -4, -6, 0, -8, -6, 0, -3, -17, 0, 0, -3], [7, -4, 4, 0, 6, 6, -2, 6, 3, -7, -10, 0, -10, -11, 0, -11, 7, -7], [-6, 6, 3, 4, -6, 4, -4, 0, -2, 4, 0, -1, 1, 2, 6, 0, -1, 2], [12, 0, 0, -3, 0, 2, 16, 2, 1, -7, -12, 1, 0, 10, -16, -5, 0, 10], [7, -13, 0, 11, 9, 13, 16, 11, -8, -14, -16, 0, -7, 0, -14, -2, 10, 2], [4, -4, -8, 1, 4, 1, 3, 0, -2, -3, 0, -9, -14, 2, -4, 0, -9, 3], [-6, -12, 12, 0, 16, 6, -4, 16, 9, 6, 12, 0, 12, -8, 0, -8, 4, -4], [0, -10, -1, 10, 0, -1, -9, 2, -2, 14, 14, -7, 9, 9, -4, -7, 9, 7], [0, 2, 7, -2, 0, 7, 11, 5, -11, -7, -7, -4, -11, 5, 7, -4, 5, -6], [0, 5, -6, -5, 0, -6, 12, -1, 7, -14, -14, 4, -12, -2, -21, 4, -2, 5], [11, 4, -12, -10, -4, -10, 3, 0, 1, -3, 0, 4, -19, -1, -11, 0, 4, 5], [-2, 10, -5, -8, -8, 0, -2, -5, 14, 0, -6, 5, 6, 0, 6, -9, -2, 5], [-1, -4, -3, -3, -3, 0, -1, -3, 1, 0, 13, 0, 2, 0, 2, -1, -8, 0], [4, 0, -1, 9, 0, 9, 0, 0, 0, 0, 0, 0, -11, 0, -4, 0, 0, 10], [0, -8, 3, 8, 0, 3, 8, 11, -6, 5, 5, -6, -8, 5, 4, -6, 5, -1], [-7, 4, -5, -5, 7, 7, 0, -4, 0, 8, -11, -3, 8, -3, -11, -4, 4, 0], [-23, 2, 0, -2, -9, -2, -16, -2, 6, 15, 16, 6, 23, -6, 15, 0, 0, 0], [-9, 7, -7, 0, 5, 2, -7, 5, -8, 9, -2, 0, -2, 6, 0, 6, -4, 4], [7, 1, 7, -4, -1, -4, -7, 0, 6, 7, 0, -3, 0, -6, -7, 0, -3, -3], [-11, 4, -1, -1, -1, -1, 0, -4, 0, 22, 12, -3, 22, 4, 12, 1, -1, 0], [10, 0, -8, -7, -8, 1, -1, 1, -13, -3, -10, -13, 0, 1, 1, -6, 0, 1], [-5, -9, 0, 0, 0, 0, 0, 9, 0, -1, 12, -3, -1, 1, 12, 1, -1, 0], [8, -3, 3, 0, 0, 4, 10, 0, -18, -8, 3, 0, 3, 3, 0, 3, 7, -7], [1, -7, 7, 0, 7, 2, -1, 7, -8, -1, 10, 0, 10, 3, 0, 3, 8, -8], [0, 7, 0, -7, 0, 0, 6, -9, -9, -1, -1, 8, -6, 1, -9, 8, 1, -8], [0, -4, -4, 4, 0, -4, 8, -7, 15, -16, -16, 3, -8, -9, -9, 3, -9, 6], [12, 10, -10, 0, -3, -7, -7, -3, 0, -12, -18, 0, -18, -1, 0, -1, -2, 2], [6, 4, -4, 0, -4, -17, 5, -4, -6, -6, 0, 0, 0, 2, 0, 2, -2, 2], [10, -14, 8, 8, 4, 4, 0, 14, 0, 14, -6, -5, 14, 4, -6, 4, -4, 0], [1, 1, 0, 3, -3, -1, -4, 3, 3, 0, 4, -3, -1, 3, 0, 1, -7, -1], [-19, -11, 11, 11, 15, 15, 0, 11, 0, 16, 18, 9, 16, 1, 18, -5, 5, 0], [-15, 0, 0, 6, -3, 0, -17, 6, -16, 11, 17, -11, 15, 11, 11, 6, -1, -6], [-13, -13, 9, 9, 11, 11, 0, 13, 0, -8, 3, -3, -8, 0, 3, -1, 1, 0], [0, 7, 0, -5, -9, -7, 2, -5, -7, 12, -2, 1, 0, -1, 12, 3, 5, -3], [-1, 0, 0, 0, -3, -12, 5, -3, 12, 1, -3, 0, -3, -1, 0, -1, 1, -1], [-4, 13, -3, -8, -8, 0, -4, -3, -3, 0, 15, -7, 13, 0, 13, -4, -9, -7], [-24, -1, 3, 7, 7, 0, -24, 3, 8, 0, 14, 2, 12, 0, 12, -6, 3, 2], [-8, 1, -1, -8, -8, 0, -8, -1, 3, 0, 7, 3, 19, 0, 19, 0, 3, 3], [3, 1, 11, -4, -1, -4, 15, 0, 4, -15, 0, -4, -14, -4, -3, 0, -4, -4], [-11, -8, 0, -6, 0, 8, -4, -6, 7, 18, 4, 10, 11, -10, 18, 6, -3, -6], [0, 2, 6, -2, 0, 6, -12, 12, 10, 12, 12, -2, 12, -5, 6, -2, -5, 5], [-7, 0, -5, 2, -5, 0, -9, 0, 1, 1, 7, 1, 0, 3, 9, 3, 0, 3], [12, -3, 3, 0, 1, 7, -2, 1, -1, -12, -24, 0, -24, -1, 0, -1, 8, -8]]
